name = "lumispy"
version = "0.2.1"
description = "Analysis of luminescence spectroscopy data with HyperSpy."
author = "The LumiSpy developers"
copyright = "Copyright 2019-2022, LumiSpy developers"
credits = ["The LumiSpy developers"]
url = "https://lumispy.org"
license = "GPLv3"
platforms = ["Linux", "Mac OSX", "Windows XP/2000/NT", "Windows 95/98/ME"]
maintainer = "Jordi Ferrer Orri, Jonas Lähnemann, Duncan Johnstone, Eric Prestat"
email = "jf631@cam.ac.uk"
status = "Development"

keywords = [
    "CL",
    "PL",
    "EL",
    "TRCL",
    "TRPL",
    "SEM",
    "STEM",
    "TEM",
    "cathodoluminescence",
    "photoluminescence",
    "electroluminescence",
    "Raman",
    "curve fitting",
    "electron microscopy",
    "hyperspectral",
    "hyperspectrum",
    "hyperspy",
    "luminescence spectroscopy",
    "lumispy",
    "machine learning",
    "model",
    "multidimensional",
    "numpy",
    "python",
    "scipy",
    "spectroscopy",
    "spectrum image",
    "time-resolved",
]
